/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
 * Description:激光点云, 视频图像以及Tf数据读取类
 * Create: 2021-08-18
 */
#include "yaml_parser.h"

using namespace ara::core;
using namespace mdc::visual;

const Vector3 YamlParser::ParseTrans(Sensor sensor, const YAML::Node &fileNode, const std::string &rootNode,
    const std::string &translationNode, const std::string &dataNode) const
{
    if (sensor == Sensor::CAMERA) {
        return Vector3(fileNode[rootNode][translationNode]["x"].as<double>(),
            fileNode[rootNode][translationNode]["y"].as<double>(),
            fileNode[rootNode][translationNode]["z"].as<double>());
    }
    return Vector3(fileNode[rootNode][translationNode][dataNode][0].as<double>(),
        fileNode[rootNode][translationNode][dataNode][1].as<double>(),
        fileNode[rootNode][translationNode][dataNode][2].as<double>());
}

const lm::LmMatrix3x3 YamlParser::ParseRotat(const YAML::Node &fileNode, const std::string &rootNode,
    const std::string &rotationNode, const std::string &dataNode) const
{
    return lm::LmMatrix3x3(fileNode[rootNode][rotationNode][dataNode][0].as<double>(),
        fileNode[rootNode][rotationNode][dataNode][1].as<double>(),
        fileNode[rootNode][rotationNode][dataNode][2].as<double>(),
        fileNode[rootNode][rotationNode][dataNode][3].as<double>(),
        fileNode[rootNode][rotationNode][dataNode][4].as<double>(),
        fileNode[rootNode][rotationNode][dataNode][5].as<double>(),
        fileNode[rootNode][rotationNode][dataNode][6].as<double>(),
        fileNode[rootNode][rotationNode][dataNode][7].as<double>(),
        fileNode[rootNode][rotationNode][dataNode][8].as<double>());
}

std::vector<double> YamlParser::ParseCamParam(const YAML::Node &fileNode, const std::string &rootNode,
    const std::string &secondNode, const std::string &dataNode) const
{
    std::vector<double> paramVec {};
    const uint32_t paramSize = fileNode[rootNode][secondNode][dataNode].size();
    for (uint32_t i = 0; i < paramSize; ++i) {
        paramVec.push_back(fileNode[rootNode][secondNode][dataNode][i].as<double>()); // 畸变系数
    }
    return paramVec;
}

const uint32_t YamlParser::ParseResolution(const YAML::Node &fileNode, const std::string &rootNode,
    const std::string &secondNode, const std::string &dataNode) const
{
    return fileNode[rootNode][secondNode][dataNode].as<uint32_t>();
}

const std::string YamlParser::ParseDistortionModel(const YAML::Node &fileNode, const std::string &rootNode,
    const std::string &secondNode) const
{
    return fileNode[rootNode][secondNode].as<std::string>();
}
